@@ -1,6 +1,9 @@
 # -*- coding: utf-8 -*-
 
-from django.conf.urls.defaults import patterns, url
+try:
+    from django.conf.urls.defaults import patterns, url
+except ImportError:  # Django 1.5
+    from django.conf.urls import patterns, url
 
 
 urlpatterns = patterns('inplaceeditform.views',
